Page 117 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 117

Home

    If it seems impossible that President Wilson could
    back such a man, it should be remembered that the
    influence behind Wilson throughout his career as
    president was Colonel Edward Mandel House, the
    Marxist (Communist) who founded the Council on
    Foreign Relations, and the man whom Wilson called his

    Calles taking away the right of the parents to educate
    their own children, and declaring his intentions to take
    possession of the consciences of the children and to

    +

    create a new national soul. In a message to the nation
    from the Governors palace of Jalisco Calles stated:

    conscience of the youth; for the youth and the child must
    belong to the Revolution.’

    belongs to the state, and only the state has the right to
    educate the child, and that all religion must be excluded
    from his teaching. This was the same philosophy adopted
    by the leaders of the French Revolution, and unfor-
    tunately, it is the same philosophy held by leading
    educators in the United States.

    Another prominent leader in the war against religion
    was Garrido Canabal, governor of Tabasco and a
    favorite of Calles. Canabal declared that education must

    112

    The Secret Side of History

    "alter ego."

    It was under Calles that some of the most outrageous

    attacks on religion occurred. These attacks began with

    We must enter into consciences and take possession
    toa a . con vena toa

    of them: the conscience of the children and the

    This declaration was based on the belief that the child